AuthorizationData class

An object representing authorization data for an Amazon ECR registry.

Constructors

AuthorizationData({String? authorizationToken, DateTime? expiresAt, String? proxyEndpoint})
AuthorizationData.fromJson(Map<String, dynamic> json)
factory

Properties

authorizationToken → String?
A base64-encoded string that contains authorization data for the specified Amazon ECR registry. When the string is decoded, it is presented in the format user:password for private registry authentication using docker login.
final
expiresAt → DateTime?
The Unix time in seconds and milliseconds when the authorization token expires. Authorization tokens are valid for 12 hours.
final
hashCode → int
The hash code for this object.
no setterinherited
proxyEndpoint → String?
The registry URL to use for this authorization token in a docker login command. The Amazon ECR registry URL format is https://aws_account_id.dkr.ecr.region.amazonaws.com. For example, https://012345678910.dkr.ecr.us-east-1.amazonaws.com..
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited