BatchCheckLayerAvailabilityResponse class

Properties

failures → List<LayerFailure>?
Any failures associated with the call.
final
hashCode → int
The hash code for this object.
no setterinherited
layers → List<Layer>?
A list of image layer objects corresponding to the image layer references in the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited