DescribeImageScanFindingsResponse class

Constructors

DescribeImageScanFindingsResponse({ImageIdentifier? imageId, ImageScanFindings? imageScanFindings, ImageScanStatus? imageScanStatus, String? nextToken, String? registryId, String? repositoryName})
DescribeImageScanFindingsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageId → ImageIdentifier?
final
imageScanFindings → ImageScanFindings?
The information contained in the image scan findings.
final
imageScanStatus → ImageScanStatus?
The current state of the scan.
final
nextToken → String?
The nextToken value to include in a future DescribeImageScanFindings request. When the results of a DescribeImageScanFindings request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
final
registryId → String?
The registry ID associated with the request.
final
repositoryName → String?
The repository name associated with the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited