nextToken property
The nextToken value to include in a future
DescribeImageScanFindings request. When the results of a
DescribeImageScanFindings request exceed
maxResults, this value can be used to retrieve the next page of
results. This value is null when there are no more results to return.
Implementation
final String? nextToken;