DescribeImagesFilter class

An object representing a filter on a DescribeImages operation.

Constructors

DescribeImagesFilter({TagStatus? tagStatus})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagStatus → TagStatus?
The tag status with which to filter your DescribeImages results. You can filter results based on whether they are TAGGED or UNTAGGED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited