ImageDetail class

An object that describes an image returned by a DescribeImages operation.

Constructors

ImageDetail({String? artifactMediaType, String? imageDigest, String? imageManifestMediaType, DateTime? imagePushedAt, ImageScanFindingsSummary? imageScanFindingsSummary, ImageScanStatus? imageScanStatus, int? imageSizeInBytes, List<String>? imageTags, String? registryId, String? repositoryName})
ImageDetail.fromJson(Map<String, dynamic> json)
factory

Properties

artifactMediaType → String?
The artifact media type of the image.
final
hashCode → int
The hash code for this object.
no setterinherited
imageDigest → String?
The sha256 digest of the image manifest.
final
imageManifestMediaType → String?
The media type of the image manifest.
final
imagePushedAt → DateTime?
The date and time, expressed in standard JavaScript date format, at which the current image was pushed to the repository.
final
imageScanFindingsSummary → ImageScanFindingsSummary?
A summary of the last completed image scan.
final
imageScanStatus → ImageScanStatus?
The current state of the scan.
final
imageSizeInBytes → int?
The size, in bytes, of the image in the repository.
final
imageTags → List<String>?
The list of tags associated with this image.
final
registryId → String?
The AWS account ID associated with the registry to which this image belongs.
final
repositoryName → String?
The name of the repository to which this image belongs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited