ImageIdentifier class

An object with identifying information for an Amazon ECR image.

Constructors

ImageIdentifier({String? imageDigest, String? imageTag})
ImageIdentifier.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageDigest → String?
The sha256 digest of the image manifest.
final
imageTag → String?
The tag used for the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited