ImageScanFinding class

Contains information about an image scan finding.

Constructors

ImageScanFinding({List<Attribute>? attributes, String? description, String? name, FindingSeverity? severity, String? uri})
ImageScanFinding.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → List<Attribute>?
A collection of attributes of the host from which the finding is generated.
final
description → String?
The description of the finding.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name associated with the finding, usually a CVE number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → FindingSeverity?
The finding severity.
final
uri → String?
A link containing additional details about the security vulnerability.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited