ImageScanFindings class

The details of an image scan.

Constructors

ImageScanFindings({Map<FindingSeverity, int>? findingSeverityCounts, List<ImageScanFinding>? findings, DateTime? imageScanCompletedAt, DateTime? vulnerabilitySourceUpdatedAt})
ImageScanFindings.fromJson(Map<String, dynamic> json)
factory

Properties

findings → List<ImageScanFinding>?
The findings from the image scan.
final
findingSeverityCounts → Map<FindingSeverity, int>?
The image vulnerability counts, sorted by severity.
final
hashCode → int
The hash code for this object.
no setterinherited
imageScanCompletedAt → DateTime?
The time of the last completed image scan.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vulnerabilitySourceUpdatedAt → DateTime?
The time when the vulnerability data was last scanned.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited