Layer class

An object representing an Amazon ECR image layer.

Constructors

Layer({LayerAvailability? layerAvailability, String? layerDigest, int? layerSize, String? mediaType})
Layer.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
layerAvailability → LayerAvailability?
The availability status of the image layer.
final
layerDigest → String?
The sha256 digest of the image layer.
final
layerSize → int?
The size, in bytes, of the image layer.
final
mediaType → String?
The media type of the layer, such as application/vnd.docker.image.rootfs.diff.tar.gzip or application/vnd.oci.image.layer.v1.tar+gzip.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited