LayerFailure class

An object representing an Amazon ECR image layer failure.

Constructors

LayerFailure({LayerFailureCode? failureCode, String? failureReason, String? layerDigest})
LayerFailure.fromJson(Map<String, dynamic> json)
factory

Properties

failureCode → LayerFailureCode?
The failure code associated with the failure.
final
failureReason → String?
The reason for the failure.
final
hashCode → int
The hash code for this object.
no setterinherited
layerDigest → String?
The layer digest associated with the failure.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited