LifecyclePolicyPreviewFilter class

The filter for the lifecycle policy preview.

Constructors

LifecyclePolicyPreviewFilter({TagStatus? tagStatus})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagStatus → TagStatus?
The tag status of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited