PutImageScanningConfigurationResponse class

Constructors

PutImageScanningConfigurationResponse({ImageScanningConfiguration? imageScanningConfiguration, String? registryId, String? repositoryName})
PutImageScanningConfigurationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageScanningConfiguration → ImageScanningConfiguration?
The image scanning configuration setting for the repository.
final
registryId → String?
The registry ID associated with the request.
final
repositoryName → String?
The repository name associated with the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited