ReplicationDestination class

An array of objects representing the details of a replication destination.

Constructors

ReplicationDestination({required String region, required String registryId})
ReplicationDestination.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
region → String
A Region to replicate to.
final
registryId → String
The account ID of the destination registry to replicate to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited