ReplicationRule class

An array of objects representing the replication destinations for a replication configuration. A replication configuration may contain only one replication rule but the rule may contain one or more replication destinations.

Constructors

ReplicationRule({required List<ReplicationDestination> destinations})
ReplicationRule.fromJson(Map<String, dynamic> json)
factory

Properties

destinations → List<ReplicationDestination>
An array of objects representing the details of a replication destination.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited