Repository class

An object representing a repository.

Constructors

Repository({DateTime? createdAt, EncryptionConfiguration? encryptionConfiguration, ImageScanningConfiguration? imageScanningConfiguration, ImageTagMutability? imageTagMutability, String? registryId, String? repositoryArn, String? repositoryName, String? repositoryUri})
Repository.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
The date and time, in JavaScript date format, when the repository was created.
final
encryptionConfiguration → EncryptionConfiguration?
The encryption configuration for the repository. This determines how the contents of your repository are encrypted at rest.
final
hashCode → int
The hash code for this object.
no setterinherited
imageScanningConfiguration → ImageScanningConfiguration?
final
imageTagMutability → ImageTagMutability?
The tag mutability setting for the repository.
final
registryId → String?
The AWS account ID associated with the registry that contains the repository.
final
repositoryArn → String?
The Amazon Resource Name (ARN) that identifies the repository. The ARN contains the arn:aws:ecr namespace, followed by the region of the repository, AWS account ID of the repository owner, repository namespace, and repository name. For example, arn:aws:ecr:region:012345678910:repository/test.
final
repositoryName → String?
The name of the repository.
final
repositoryUri → String?
The URI for the repository. You can use this URI for container image push and pull operations.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited