StartImageScanResponse class

Constructors

StartImageScanResponse({ImageIdentifier? imageId, ImageScanStatus? imageScanStatus, String? registryId, String? repositoryName})
StartImageScanResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageId → ImageIdentifier?
final
imageScanStatus → ImageScanStatus?
The current state of the scan.
final
registryId → String?
The registry ID associated with the request.
final
repositoryName → String?
The repository name associated with the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited