UploadLayerPartResponse class

Constructors

UploadLayerPartResponse({int? lastByteReceived, String? registryId, String? repositoryName, String? uploadId})
UploadLayerPartResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastByteReceived → int?
The integer value of the last byte received in the request.
final
registryId → String?
The registry ID associated with the request.
final
repositoryName → String?
The repository name associated with the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadId → String?
The upload ID associated with the request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited